==================================
Ask general questions about Aydin
==================================

If you like to ask any questions about using Aydin,
best way to reach us is `image.sc forum <https://forum.image.sc/tag/aydin>`_.
